package
Version:
v0.1.0-alpha
Opens a new window with list of versions in this module.
Published: Mar 14, 2023
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Release struct {
ReleaseName string `yaml:"releaseName"`
RepoURL string `yaml:"repoURL"`
Chart string `yaml:"chart"`
Version string `yaml:"version"`
Namespace string `yaml:"namespace"`
Values map[string]interface{} `yaml:"values,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.